# Generated by Django 4.2.5 on 2023-09-23 12:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("users", "0003_alter_customuser_managers"),
    ]

    operations = [
        migrations.AlterField(
            model_name="customuser",
            name="date_of_birth",
            field=models.DateField(blank=True, null=True, verbose_name="Date of Birth"),
        ),
    ]
