# Generated by Django 4.2.5 on 2023-09-24 11:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("users", "0004_alter_customuser_date_of_birth"),
    ]

    operations = [
        migrations.AddField(
            model_name="customuser",
            name="archive",
            field=models.BooleanField(default=False, verbose_name="Archive"),
        ),
    ]
