# Generated by Django 4.2.5 on 2023-09-23 12:25

from django.db import migrations
import users.managers


class Migration(migrations.Migration):
    dependencies = [
        ("users", "0002_alter_customuser_email"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="customuser",
            managers=[
                ("objects", users.managers.CustomUserManager()),
            ],
        ),
    ]
