{% extends "base.html" %} 

{% load static %} 

{% load crispy_forms_tags %} 

{%block styles %}
<link rel="stylesheet" href="{% static 'users/styles.css' %}" />
{% endblock styles %} 

{% block title %}
<title>Login</title>
{% endblock title %} 

{% block content %}

    <div class="container">
        <div class="card flex flex-col justify-center align-items-center mx-auto col-md-8">
            <form method="post" class="flex flex-col justify-start items-start col-md-6 card-body">
                {% csrf_token %}
                {% crispy form %} 
                {% comment %} {{form.errors}} {% endcomment %}
                {% comment %} <button type='submit' class='btn btn-success col-md-6 px-10'>Login</button> {% endcomment %}
            </form>
            <br>
            <div class="col-md-6 card-body">
                <p>Don't have an account?</p>
                <a href="{% url 'users:user_register' %}"> Register</a>
            </div>
        </div>
    </div>

{% endblock content %}
